.. some inspiration from dogpile.cache docs

Welcome to tinyshar's documentation!
====================================

.. toctree::
   :maxdepth: 2

   front
   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
